@@ -42,33 +42,26 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
                 "angular": [{"section": "Unknown", "i_commits": [0]}],
                 "emoji": [{"section": "Other", "i_commits": [0]}],
                 "scipy": [{"section": "Unknown", "i_commits": [0]}],
-                "tag": [{"section": "Unknown", "i_commits": [0]}],
             },
             "commits": [
                 {
                     "angular": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
                     "emoji": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
                     "scipy": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
-                    "tag": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
                 },
             ],
         },
         "0.1.1-rc.1": {
             "changelog_sections": {
-                "angular": [{"section": "Fixes", "i_commits": [0]}],
+                "angular": [{"section": "Bug Fixes", "i_commits": [0]}],
                 "emoji": [{"section": ":bug:", "i_commits": [0]}],
                 "scipy": [{"section": "Fix", "i_commits": [0]}],
-                "tag": [{"section": "Fix", "i_commits": [0]}],
             },
             "commits": [
                 {
                     "angular": {"msg": "fix: correct some text", "sha": NULL_HEX_SHA},
                     "emoji": {"msg": ":bug: correct some text", "sha": NULL_HEX_SHA},
                     "scipy": {"msg": "MAINT: correct some text", "sha": NULL_HEX_SHA},
-                    "tag": {
-                        "msg": ":nut_and_bolt: correct some text",
-                        "sha": NULL_HEX_SHA,
-                    },
                 }
             ],
         },
@@ -77,7 +70,6 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
                 "angular": [{"section": "Breaking", "i_commits": [0]}],
                 "emoji": [{"section": ":boom:", "i_commits": [0]}],
                 "scipy": [{"section": "Breaking", "i_commits": [0]}],
-                "tag": [{"section": "Breaking", "i_commits": [0]}],
             },
             "commits": [
                 {
@@ -93,10 +85,6 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
                         "msg": "API: add revolutionary feature",
                         "sha": NULL_HEX_SHA,
                     },
-                    "tag": {
-                        "msg": ":sparkles: add revolutionary feature\n\nBREAKING CHANGE: add revolutionary feature",
-                        "sha": NULL_HEX_SHA,
-                    },
                 }
             ],
         },
@@ -105,7 +93,6 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
                 "angular": [{"section": "Features", "i_commits": [0]}],
                 "emoji": [{"section": ":sparkles:", "i_commits": [0]}],
                 "scipy": [{"section": "Feature", "i_commits": [0]}],
-                "tag": [{"section": "Feature", "i_commits": [0]}],
             },
             "commits": [
                 {
@@ -115,10 +102,6 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
                         "sha": NULL_HEX_SHA,
                     },
                     "scipy": {"msg": "ENH: add some more text", "sha": NULL_HEX_SHA},
-                    "tag": {
-                        "msg": ":sparkles: add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
                 }
             ],
         },
@@ -127,7 +110,6 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
                 "angular": [{"section": "Features", "i_commits": [0]}],
                 "emoji": [{"section": ":sparkles:", "i_commits": [0]}],
                 "scipy": [{"section": "Feature", "i_commits": [0]}],
-                "tag": [{"section": "Feature", "i_commits": [0]}],
             },
             "commits": [
                 {
@@ -143,19 +125,14 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
                         "msg": "ENH(dev): add some more text",
                         "sha": NULL_HEX_SHA,
                     },
-                    "tag": {
-                        "msg": ":sparkles: (dev) add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
                 }
             ],
         },
         "1.1.1": {
             "changelog_sections": {
-                "angular": [{"section": "Fixes", "i_commits": [0]}],
+                "angular": [{"section": "Bug Fixes", "i_commits": [0]}],
                 "emoji": [{"section": ":bug:", "i_commits": [0]}],
                 "scipy": [{"section": "Fix", "i_commits": [0]}],
-                "tag": [{"section": "Fix", "i_commits": [0]}],
             },
             "commits": [
                 {
@@ -171,10 +148,6 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
                         "msg": "MAINT(dev): correct some text",
                         "sha": NULL_HEX_SHA,
                     },
-                    "tag": {
-                        "msg": ":nut_and_bolt: correct dev-scoped text",
-                        "sha": NULL_HEX_SHA,
-                    },
                 }
             ],
         },
@@ -183,7 +156,6 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
                 "angular": [{"section": "Features", "i_commits": [0]}],
                 "emoji": [{"section": ":sparkles:", "i_commits": [0]}],
                 "scipy": [{"section": "Feature", "i_commits": [0]}],
-                "tag": [{"section": "Feature", "i_commits": [0]}],
             },
             "commits": [
                 {
@@ -199,7 +171,6 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
                         "msg": "ENH(scope): add some more text",
                         "sha": NULL_HEX_SHA,
                     },
-                    "tag": {"msg": ":sparkles: add scoped change", "sha": NULL_HEX_SHA},
                 }
             ],
         },
@@ -209,8 +180,8 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
                 # But value is ultimately defined by the commits, which means the commits are
                 # referenced by index value
                 "angular": [
+                    {"section": "Bug Fixes", "i_commits": [1]},
                     {"section": "Features", "i_commits": [0]},
-                    {"section": "Fixes", "i_commits": [1]},
                 ],
                 "emoji": [
                     {"section": ":bug:", "i_commits": [1]},
@@ -220,10 +191,6 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
                     {"section": "Feature", "i_commits": [0]},
                     {"section": "Fix", "i_commits": [1]},
                 ],
-                "tag": [
-                    {"section": "Feature", "i_commits": [0]},
-                    {"section": "Fix", "i_commits": [1]},
-                ],
             },
             "commits": [
                 {
@@ -239,7 +206,6 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
                         "msg": "ENH(scope): add some more text",
                         "sha": NULL_HEX_SHA,
                     },
-                    "tag": {"msg": ":sparkles: add scoped change", "sha": NULL_HEX_SHA},
                 },
                 {
                     "angular": {
@@ -254,10 +220,6 @@ def get_commits_for_git_flow_repo_with_2_release_channels() -> GetRepoDefinition
                         "msg": "MAINT(scope): correct some text",
                         "sha": NULL_HEX_SHA,
                     },
-                    "tag": {
-                        "msg": ":nut_and_bolt: correct feature-scoped text",
-                        "sha": NULL_HEX_SHA,
-                    },
                 },
             ],
         },
@@ -663,19 +625,6 @@ def cached_repo_w_git_flow_n_2_release_channels_scipy_commits(
     return teardown_cached_dir(cached_repo_path)
 
 
-@pytest.fixture(scope="session")
-def cached_repo_w_git_flow_n_2_release_channels_tag_commits(
-    build_git_flow_repo_with_2_release_channels: BuildRepoFn,
-    cached_files_dir: Path,
-    teardown_cached_dir: TeardownCachedDirFn,
-) -> Path:
-    cached_repo_path = cached_files_dir.joinpath(
-        cached_repo_w_git_flow_n_2_release_channels_tag_commits.__name__
-    )
-    build_git_flow_repo_with_2_release_channels(cached_repo_path, "tag")
-    return teardown_cached_dir(cached_repo_path)
-
-
 # --------------------------------------------------------------------------- #
 # Test-level fixtures to use to set up temporary test directory               #
 # --------------------------------------------------------------------------- #
@@ -727,19 +676,3 @@ def repo_with_git_flow_scipy_commits(
         example_project_dir,
     )
     return example_project_git_repo()
-
-
-@pytest.fixture
-def repo_with_git_flow_tag_commits(
-    cached_repo_w_git_flow_n_2_release_channels_tag_commits: Path,
-    example_project_git_repo: ExProjectGitRepoFn,
-    example_project_dir: ExProjectDir,
-    change_to_ex_proj_dir: None,
-) -> Repo:
-    if not cached_repo_w_git_flow_n_2_release_channels_tag_commits.exists():
-        raise RuntimeError("Unable to find cached repository!")
-    copy_dir_tree(
-        cached_repo_w_git_flow_n_2_release_channels_tag_commits,
-        example_project_dir,
-    )
-    return example_project_git_repo()
