@@ -42,33 +42,26 @@ def get_commits_for_github_flow_repo_w_feature_release_channel() -> GetRepoDefin
                 "angular": [{"section": "Unknown", "i_commits": [0]}],
                 "emoji": [{"section": "Other", "i_commits": [0]}],
                 "scipy": [{"section": "Unknown", "i_commits": [0]}],
-                "tag": [{"section": "Unknown", "i_commits": [0]}],
             },
             "commits": [
                 {
                     "angular": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
                     "emoji": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
                     "scipy": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
-                    "tag": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
                 },
             ],
         },
         "0.1.1-rc.1": {
             "changelog_sections": {
-                "angular": [{"section": "Fixes", "i_commits": [0]}],
+                "angular": [{"section": "Bug Fixes", "i_commits": [0]}],
                 "emoji": [{"section": ":bug:", "i_commits": [0]}],
                 "scipy": [{"section": "Fix", "i_commits": [0]}],
-                "tag": [{"section": "Fix", "i_commits": [0]}],
             },
             "commits": [
                 {
                     "angular": {"msg": "fix: correct some text", "sha": NULL_HEX_SHA},
                     "emoji": {"msg": ":bug: correct some text", "sha": NULL_HEX_SHA},
                     "scipy": {"msg": "MAINT: correct some text", "sha": NULL_HEX_SHA},
-                    "tag": {
-                        "msg": ":nut_and_bolt: correct some text",
-                        "sha": NULL_HEX_SHA,
-                    },
                 }
             ],
         },
@@ -77,7 +70,6 @@ def get_commits_for_github_flow_repo_w_feature_release_channel() -> GetRepoDefin
                 "angular": [{"section": "Features", "i_commits": [0]}],
                 "emoji": [{"section": ":sparkles:", "i_commits": [0]}],
                 "scipy": [{"section": "Feature", "i_commits": [0]}],
-                "tag": [{"section": "Feature", "i_commits": [0]}],
             },
             "commits": [
                 {
@@ -87,10 +79,6 @@ def get_commits_for_github_flow_repo_w_feature_release_channel() -> GetRepoDefin
                         "sha": NULL_HEX_SHA,
                     },
                     "scipy": {"msg": "ENH: add some more text", "sha": NULL_HEX_SHA},
-                    "tag": {
-                        "msg": ":sparkles: add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
                 }
             ],
         },
@@ -99,7 +87,6 @@ def get_commits_for_github_flow_repo_w_feature_release_channel() -> GetRepoDefin
                 "angular": [{"section": "Features", "i_commits": [0]}],
                 "emoji": [{"section": ":sparkles:", "i_commits": [0]}],
                 "scipy": [{"section": "Feature", "i_commits": [0]}],
-                "tag": [{"section": "Feature", "i_commits": [0]}],
             },
             "commits": [
                 {
@@ -109,10 +96,6 @@ def get_commits_for_github_flow_repo_w_feature_release_channel() -> GetRepoDefin
                         "sha": NULL_HEX_SHA,
                     },
                     "scipy": {"msg": "ENH: add some more text", "sha": NULL_HEX_SHA},
-                    "tag": {
-                        "msg": ":sparkles: add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
                 }
             ],
         },
@@ -121,7 +104,6 @@ def get_commits_for_github_flow_repo_w_feature_release_channel() -> GetRepoDefin
                 "angular": [{"section": "Features", "i_commits": [0]}],
                 "emoji": [{"section": ":sparkles:", "i_commits": [0]}],
                 "scipy": [{"section": "Feature", "i_commits": [0]}],
-                "tag": [{"section": "Feature", "i_commits": [0]}],
             },
             "commits": [
                 {
@@ -134,7 +116,6 @@ def get_commits_for_github_flow_repo_w_feature_release_channel() -> GetRepoDefin
                         "msg": "ENH(scope): add some more text",
                         "sha": NULL_HEX_SHA,
                     },
-                    "tag": {"msg": ":sparkles: add scoped text", "sha": NULL_HEX_SHA},
                 }
             ],
         },
@@ -429,19 +410,6 @@ def cached_repo_w_github_flow_w_feature_release_channel_scipy_commits(
     return teardown_cached_dir(cached_repo_path)
 
 
-@pytest.fixture(scope="session")
-def cached_repo_w_github_flow_w_feature_release_channel_tag_commits(
-    build_github_flow_repo_w_feature_release_channel: BuildRepoFn,
-    cached_files_dir: Path,
-    teardown_cached_dir: TeardownCachedDirFn,
-) -> Path:
-    cached_repo_path = cached_files_dir.joinpath(
-        cached_repo_w_github_flow_w_feature_release_channel_tag_commits.__name__
-    )
-    build_github_flow_repo_w_feature_release_channel(cached_repo_path, "tag")
-    return teardown_cached_dir(cached_repo_path)
-
-
 # --------------------------------------------------------------------------- #
 # Test-level fixtures to use to set up temporary test directory               #
 # --------------------------------------------------------------------------- #
@@ -493,19 +461,3 @@ def repo_w_github_flow_w_feature_release_channel_scipy_commits(
         example_project_dir,
     )
     return example_project_git_repo()
-
-
-@pytest.fixture
-def repo_w_github_flow_w_feature_release_channel_tag_commits(
-    cached_repo_w_github_flow_w_feature_release_channel_tag_commits: Path,
-    example_project_git_repo: ExProjectGitRepoFn,
-    example_project_dir: Path,
-    change_to_ex_proj_dir: None,
-) -> Repo:
-    if not cached_repo_w_github_flow_w_feature_release_channel_tag_commits.exists():
-        raise RuntimeError("Unable to find cached repository!")
-    copy_dir_tree(
-        cached_repo_w_github_flow_w_feature_release_channel_tag_commits,
-        example_project_dir,
-    )
-    return example_project_git_repo()
